////////////////////////////////////////////////////////////
// platform.h
//
// Header file describing platform choices for EDrive, a multiplatform
// driving simulator.
//
// While the current release only supports two platform combinations,
// Windows (all DirectX 9) and Linux (OpenGL, GLUT and OpenAL) the code
// has been written in such a way so that various other branches (such
// as Windows using OpenGL and GLUT) could be added in without much
// rewriting of existing code, just addition of new code.
//
// Copyright 2004 by Evan Alexander Weaver
// 
// Despite the copyright, this is free software. See edrive.cpp for details.
//
// Date last modified: 31 May 2004

#ifndef _edrive_platform_h_
#define _edrive_platform_h_

// Uncomment one of the two following lines:
//#define ED_LINUX 0
#define ED_LINUX 1

// Currently, everything else comes from that choice. Hopefully the names
// of the individual component choices are obvious. Each choice must be
// given a value of true (1) or false (0), and you need to be careful
// in managing which combination of choices are true at any one time.

#if ED_LINUX
    #define ED_WINDOWS 0
    #define ED_DIRECTX 0
    #define ED_DIRECTX_9 0
    #define ED_DIRECTX_9_GRAPHICS 0
    #define ED_DIRECTX_9_INPUT 0
    #define ED_DIRECTX_9_AUDIO 0
    #define ED_OPENGL 1
    #define ED_OPENGL_GLUT 1
    #define ED_OPENAL 1
#else
    #define ED_WINDOWS 1
    #define ED_DIRECTX 1
    #define ED_DIRECTX_9 1
    #define ED_DIRECTX_9_GRAPHICS 1
    #define ED_DIRECTX_9_INPUT 1
    #define ED_DIRECTX_9_AUDIO 1
    #define ED_OPENGL 0
    #define ED_OPENGL_GLUT 0
    #define ED_OPENAL 0
#endif

#endif
